@@ -18,6 +18,6 @@
 
 #define NL_MAJOR 2
 #define NL_MINOR 2
-#define NL_REV   5
-#define NL_DATE  "Mar 10, 2006"
-#define VERSION  "2.2.5"
+#define NL_REV   7
+#define NL_DATE  "Sep 02, 2006"
+#define VERSION  "2.2.7"
